@@ -2,8 +2,7 @@ package Net::IPAddress::Util;
 
 use strict;
 use warnings;
-use 5.012;
-use utf8;
+use 5.010;
 
 use overload (
     '=' => 'new',
@@ -44,7 +43,7 @@ $EXPORT_TAGS{ all } = [@EXPORT_OK];
 our $DIE_ON_ERROR = 0;
 our $PROMOTE_N32 = 1;
 
-our $VERSION = '3.022';
+our $VERSION = '3.024';
 
 sub IP {
     return Net::IPAddress::Util->new($_[0]);
@@ -197,7 +196,8 @@ sub ipv6 {
     my $rv = $self->ipv6_expanded();
     $rv =~ s/(?::)(0+:)+/::/;
     $rv =~ s/^0+//;
-    $rv =~ s/:0+/:/g;
+    $rv =~ s/:0+([^0])/:$1/g;
+    $rv =~ s/:0+$/:/;
     $rv =~ s/^:/::/;
     return $rv;
 }
