@@ -2,8 +2,7 @@ package Net::IPAddress::Util::Collection;
 
 use strict;
 use warnings;
-use 5.012;
-use utf8;
+use 5.010;
 
 require Net::IPAddress::Util;
 require Net::IPAddress::Util::Collection::Tie;
@@ -23,7 +22,7 @@ sub sorted {
     my $self = shift;
     # In theory, a raw radix sort is O(N), which beats Perl's O(N log N) by
     # a fair margin. However, it _does_ discard duplicates, so ymmv.
-    my $from = [ map { [ unpack('U32', $_->{ lower }->{ address } . $_->{ upper }->{ address }) ] } @$self ];
+    my $from = [ map { [ unpack('C32', $_->{ lower }->{ address } . $_->{ upper }->{ address }) ] } @$self ];
     my $to;
     for (my $i = 31; $i >= 0; $i--) {
         $to = [];
@@ -92,7 +91,7 @@ Net::IPAddress::Util::Collection - A collection of Net::IPAddress::Util::Range o
 
 =head1 VERSION
 
-Version 3.020
+Version 3.023
 
 =head1 SYNOPSIS
 
